@@ -2,7 +2,7 @@ from typing import Optional
 
 from pyspark.sql.functions import udf
 from pyspark.sql.types import IntegerType
-
+from pyspark.sql.column import Column, _to_java_column, _to_seq
 
 class UDFBase:
     sparkSession = None
@@ -29,3 +29,8 @@ def rest_api(*cols):
     )
     rest_api_response = udfConfig.UDFUtils.rest_api(_cols)
     return 1
+
+def call_udf(udfName: str, *cols):
+    _cols = _to_seq(udfConfig.sparkSession.sparkContext, cols, _to_java_column)
+    call_udf_result = udfConfig.UDFUtils.call_udf(udfName, _cols)
+    return Column(call_udf_result)
\ No newline at end of file
