@@ -83,6 +83,33 @@ class InterimConfig:
 interimConfig = InterimConfig()
 
 
+class ProphecyDebugger:
+
+    @classmethod
+    def sparkSql(cls, spark: SparkSession, query: str):
+        return spark.sparkContext._jvm.org.apache.spark.sql.ProphecyDebugger.sparkSql(spark._jsparkSession, query)
+
+    @classmethod
+    def exception(cls, spark: SparkSession):
+        spark.sparkContext._jvm.org.apache.spark.sql.ProphecyDebugger.exception(spark._jsparkSession)
+
+    @classmethod
+    def class_details(cls, spark: SparkSession, name: str):
+        return spark.sparkContext._jvm.org.apache.spark.sql.ProphecyDebugger.classDetails(spark._jsparkSession, name)
+
+    @classmethod
+    def spark_conf(cls, spark: SparkSession):
+        return spark.sparkContext._jvm.org.apache.spark.sql.ProphecyDebugger.sparkConf(spark._jsparkSession)
+    @classmethod
+    def runtime_conf(cls, spark: SparkSession):
+        return spark.sparkContext._jvm.org.apache.spark.sql.ProphecyDebugger.runtimeConf(spark._jsparkSession)
+    @classmethod
+    def local_properties(cls, spark: SparkSession):
+        return spark.sparkContext._jvm.org.apache.spark.sql.ProphecyDebugger.localProperties(spark._jsparkSession)
+    @classmethod
+    def get_scala_object(cls, spark: SparkSession, className: str):
+        return spark.sparkContext._jvm.org.apache.spark.sql.ProphecyDebugger.getScalaObject(spark._jsparkSession, className)
+
 class MetricsCollector:
 
     # Called only for interactive execution and metrics mode.
